Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(34)

Unified Diff: remoting/host/video_scheduler.h

Issue 455073004: Switch DesktopEnvironment to return a DesktopCapturer. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Remove ShapedDesktopCapturer::Create() Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/shaped_screen_capturer_unittest.cc ('k') | remoting/host/video_scheduler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/video_scheduler.h
diff --git a/remoting/host/video_scheduler.h b/remoting/host/video_scheduler.h
index 21b100731851fca85dc9ed851bc688c2341eabab..13ef218b0ca4734f815e58286970d106376af9b2 100644
--- a/remoting/host/video_scheduler.h
+++ b/remoting/host/video_scheduler.h
@@ -15,15 +15,15 @@
#include "remoting/codec/video_encoder.h"
#include "remoting/host/capture_scheduler.h"
#include "remoting/proto/video.pb.h"
+#include "third_party/webrtc/modules/desktop_capture/desktop_capturer.h"
#include "third_party/webrtc/modules/desktop_capture/mouse_cursor_monitor.h"
-#include "third_party/webrtc/modules/desktop_capture/screen_capturer.h"
namespace base {
class SingleThreadTaskRunner;
} // namespace base
namespace media {
-class ScreenCapturer;
+class DesktopCapturer;
} // namespace media
namespace remoting {
@@ -37,7 +37,7 @@ class VideoStub;
} // namespace protocol
// Class responsible for scheduling frame captures from a
// webrtc::ScreenCapturer, delivering them to a VideoEncoder to encode, and
// finally passing the encoded video packets to the specified VideoStub to send
// on the network.
//
@@ -88,7 +88,7 @@ class VideoScheduler : public base::RefCountedThreadSafe<VideoScheduler>,
scoped_refptr<base::SingleThreadTaskRunner> capture_task_runner,
scoped_refptr<base::SingleThreadTaskRunner> encode_task_runner,
scoped_refptr<base::SingleThreadTaskRunner> network_task_runner,
- scoped_ptr<webrtc::ScreenCapturer> capturer,
+ scoped_ptr<webrtc::DesktopCapturer> capturer,
scoped_ptr<webrtc::MouseCursorMonitor> mouse_cursor_monitor,
scoped_ptr<VideoEncoder> encoder,
protocol::CursorShapeStub* cursor_stub,
@@ -180,7 +180,7 @@ class VideoScheduler : public base::RefCountedThreadSafe<VideoScheduler>,
scoped_refptr<base::SingleThreadTaskRunner> network_task_runner_;
// Used to capture frames. Always accessed on the capture thread.
- scoped_ptr<webrtc::ScreenCapturer> capturer_;
+ scoped_ptr<webrtc::DesktopCapturer> capturer_;
// Used to capture mouse cursor shapes. Always accessed on the capture thread.
scoped_ptr<webrtc::MouseCursorMonitor> mouse_cursor_monitor_;
« no previous file with comments | « remoting/host/shaped_screen_capturer_unittest.cc ('k') | remoting/host/video_scheduler.cc » ('j') | no next file with comments »
@@ -37,7 +37,7 @@ class VideoStub;
} // namespace protocol
// Class responsible for scheduling frame captures from a
-// webrtc::ScreenCapturer, delivering them to a VideoEncoder to encode, and
+// webrtc::DesktopCapturer, delivering them to a VideoEncoder to encode, and
// finally passing the encoded video packets to the specified VideoStub to send
// on the network.

Powered by Google App Engine
This is Rietveld 408576698